@@ -14,7 +14,7 @@ class Command(BaseCommand):
     """
     option_list = BaseCommand.option_list + (
         make_option('--app-label',dest='app_label',help='The app label to which the local model belongs.'),
-        make_option('--local-model',dest='local_model',help='The name of the local model'),
+        make_option('--local-model',dest='local_mod',help='The name of the local model'),
         make_option('--local-id',dest='local_id',help='The id of the local model'),
         make_option('--content-key',dest='content_key',help='The ACE content key to associate.'),
     )
@@ -26,17 +26,17 @@ class Command(BaseCommand):
         print 'options are:',options
         content_type = None
         try:
-            content_type = ContentType.objects.get(app_label=options['app_label'],model=options['local_model'])
+            content_type = ContentType.objects.get(app_label=options['app_label'],model=options['local_mod'])
         except ContentType.DoesNotExist:
             raise CommandError('No such local content type.')
         
-        local_model = content_type.model_class()
-        if not hasattr(local_model,'ACE'):
-            raise CommandError('Local model %s is not configured to be linked to ACE.' % options['local_model'])
+        local_mod = content_type.model_class()
+        if not hasattr(local_mod,'ACE'):
+            raise CommandError('Local model %s is not configured to be linked to ACE.' % options['local_mod'])
         
         AxilentContentRecord.objects.create(local_content_type=content_type,
                                             local_id=options['local_id'],
-                                            axilent_content_type=local_model.ACE.content_type,
+                                            axilent_content_type=local_mod.ACE.content_type,
                                             axilent_content_key=options['content_key'])
         
         print 'ACE content record created'
